@@ -26,36 +26,34 @@ namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-class IndexStatsContent : public eckit::Counted,
-                          public eckit::Statistics,
-                          public eckit::Streamable {
+class IndexStatsContent : public eckit::Counted, public eckit::Statistics, public eckit::Streamable {
 public:
 
     ~IndexStatsContent() override;
 
-    virtual size_t fieldsCount() const = 0;
+    virtual size_t fieldsCount() const     = 0;
     virtual size_t duplicatesCount() const = 0;
 
-    virtual size_t fieldsSize() const = 0;
+    virtual size_t fieldsSize() const     = 0;
     virtual size_t duplicatesSize() const = 0;
 
-    virtual size_t addFieldsCount(size_t) = 0;
+    virtual size_t addFieldsCount(size_t)     = 0;
     virtual size_t addDuplicatesCount(size_t) = 0;
 
-    virtual size_t addFieldsSize(size_t i) = 0;
+    virtual size_t addFieldsSize(size_t i)     = 0;
     virtual size_t addDuplicatesSize(size_t i) = 0;
 
     virtual void add(const IndexStatsContent&) = 0;
 
     virtual void report(std::ostream& out, const char* indent) const = 0;
 
-public: // For Streamable
+public:  // For Streamable
 
     void encode(eckit::Stream& s) const override = 0;
 
-protected: // For Streamable
+protected:  // For Streamable
 
-    static eckit::ClassSpec                  classSpec_;
+    static eckit::ClassSpec classSpec_;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -64,7 +62,7 @@ protected: // For Streamable
 
 class IndexStats {
 
-public: // methods
+public:  // methods
 
     IndexStats();
     IndexStats(IndexStatsContent*);
@@ -75,7 +73,7 @@ public: // methods
 
     IndexStats& operator=(const IndexStats&);
 
-    IndexStats& operator+= (const IndexStats& rhs);
+    IndexStats& operator+=(const IndexStats& rhs);
 
     size_t fieldsCount() const { return content_->fieldsCount(); }
     size_t duplicatesCount() const { return content_->duplicatesCount(); }
@@ -93,18 +91,19 @@ public: // methods
 
     void report(std::ostream& out, const char* indent = "") const;
 
-//    template <class T>
-//    T& as() {
-//        return dynamic_cast<T&>(*content_);
-//    }
+    //    template <class T>
+    //    T& as() {
+    //        return dynamic_cast<T&>(*content_);
+    //    }
 
-private: // methods
+private:  // methods
 
     void print(std::ostream&) const;
     void encode(eckit::Stream& s) const;
 
     friend std::ostream& operator<<(std::ostream& s, const IndexStats& o) {
-        o.print(s); return s;
+        o.print(s);
+        return s;
     }
 
     friend eckit::Stream& operator<<(eckit::Stream& s, const IndexStats& r) {
@@ -112,13 +111,13 @@ private: // methods
         return s;
     }
 
-private: // members
+private:  // members
 
     IndexStatsContent* content_;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
 #endif
