@@ -37,9 +37,12 @@ class FDBCopy : public fdb5::tools::FDBVisitTool {
     bool fromList_ = false;
     bool sort_     = false;
 
+    std::string modifiers_;
+
     eckit::PathName sourceConfig_ = {};
     eckit::PathName targetConfig_ = {};
 
+    void checkModifiers(const metkit::mars::MarsRequest&, const eckit::StringDict&);
     void execute(const CmdArgs& args) override;
     void usage(const std::string& tool) const override;
     void init(const CmdArgs& args) override;
@@ -56,6 +59,11 @@ FDBCopy::FDBCopy(int argc, char** argv) : fdb5::tools::FDBVisitTool(argc, argv,
     options_.push_back(new SimpleOption<eckit::PathName>("source", "Configuration of FDB to read from"));
     options_.push_back(new eckit::option::SimpleOption<bool>(
         "from-list", "Interpret argument(s) as fdb-list partial requests, rather than request files"));
+    options_.push_back(new eckit::option::SimpleOption<std::string>(
+        "modifiers",
+        "List of comma separated key-values of modifiers to each message "
+        "in input data. The modifier keys must also be present in the "
+        "supplied request. Example: --modifiers=expver=0042,date=20190603"));
 }
 
 void FDBCopy::usage(const std::string& tool) const {
@@ -82,6 +90,8 @@ void FDBCopy::init(const CmdArgs& args) {
 
     FDBVisitTool::init(args);
 
+    args.get("modifiers", modifiers_);
+
     verbose_  = args.getBool("verbose", verbose_);
     fromList_ = args.getBool("from-list", fromList_);
     sort_     = args.getBool("sort", sort_);
@@ -129,6 +139,16 @@ static std::vector<metkit::mars::MarsRequest> readRequestsFromFile(const CmdArgs
     return requests;
 }
 
+void FDBCopy::checkModifiers(const metkit::mars::MarsRequest& request, const eckit::StringDict& modifiers) {
+    for (const auto& pair : modifiers) {
+        if (!request.has(pair.first)) {
+            std::ostringstream msg;
+            msg << "Provided modifiers for key '" << pair.first << "' not present in data to be copied";
+            throw eckit::UserError(msg.str());
+        }
+    }
+}
+
 void FDBCopy::execute(const CmdArgs& args) {
 
     fdb5::Config readConfig  = fdb5::Config::make(sourceConfig_);
@@ -137,8 +157,12 @@ void FDBCopy::execute(const CmdArgs& args) {
     fdb5::HandleGatherer handles(sort_);
     fdb5::FDB fdbRead(readConfig);
 
+    // parse modifiers if any
+    eckit::StringDict modifiers = fdb5::Key::parse(modifiers_).keyDict();
+
     if (fromList_) {
         for (const FDBToolRequest& request : requests("list")) {
+            checkModifiers(request.request(), modifiers);
             bool deduplicate = true;
             auto listObject  = fdbRead.list(request, deduplicate);
             handles.add(fdbRead.read(listObject, sort_));
@@ -147,6 +171,7 @@ void FDBCopy::execute(const CmdArgs& args) {
     else {
         std::vector<metkit::mars::MarsRequest> requests = readRequestsFromFile(args);
         for (const auto& request : requests) {
+            checkModifiers(request, modifiers);
             eckit::Log::info() << request << std::endl;
             handles.add(fdbRead.retrieve(request));
         }
@@ -155,6 +180,7 @@ void FDBCopy::execute(const CmdArgs& args) {
     std::unique_ptr<eckit::DataHandle> dh(handles.dataHandle());
 
     fdb5::MessageArchiver fdbWriter(fdb5::Key(), false, verbose_, writeConfig);
+    fdbWriter.setModifiers(modifiers);
     fdbWriter.archive(*dh);
 }
 
